Crate atom_file

Crate atom_file 

AtomicFile provides buffered concurrent access to files with async atomic commit.

BasicAtomicFile is a non-async alternative.

Structs

AtomicFile
Based on BasicAtomicFile which makes sure that updates are all-or-nothing. Performs commit asyncronously.
BasicAtomicFile
Basis for crate::AtomicFile ( non-async alternative ). Provides two-phase commit and buffering of reads and writes.
DummyFile
Dummy Stg that can be used for Atomic upd file if “reliable” atomic commits are not required.
Limits
Memory configuration limits.
MemFile
Simple implementation of Storage using Vec<u8>.
MultiFileStorage
Alternative to SimpleFileStorage that uses multiple SimpleFileStorages to allow parallel reads/writes by different threads.
SimpleFileStorage
Simple implementation of Storage using std::fs::File.

Traits

Storage
Storage interface - Storage is some kind of “file” storage.

Type Aliases

Data
Arc<Vec<u8>>