#[non_exhaustive]pub struct Limits {
pub map_lim: usize,
pub rbuf_mem: usize,
pub swbuf: usize,
pub uwbuf: usize,
}Expand description
Memory configuration limits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.map_lim: usizeLimit on size of commit write map, default is 5000.
rbuf_mem: usizeMemory for buffering small reads, default is 0x200000.
swbuf: usizeMemory for buffering writes to main storage, default is 0x100000.
uwbuf: usizeMemory for buffering writes to temporary storage, default is 0x100000.