Storage

Trait Storage 

pub trait Storage: Send + Sync {
    // Required methods
    fn size(&self) -> u64;
    fn read(&self, start: u64, data: &mut [u8]);
    fn write(&mut self, start: u64, data: &[u8]);
    fn commit(&mut self, size: u64);

    // Provided methods
    fn write_vec(&mut self, start: u64, data: Vec<u8>) { ... }
    fn write_data(&mut self, start: u64, data: Data, off: usize, len: usize) { ... }
    fn write_u64(&mut self, start: u64, value: u64) { ... }
    fn read_u64(&self, start: u64) -> u64 { ... }
    fn clone(&self) -> Box<dyn Storage> { ... }
    fn wait_complete(&self) { ... }
}
Storage interface - Storage is some kind of “file” storage.

read and write methods take a start which is a byte offset in the underlying file.

Required Methods

fn size(&self) -> u64

Get the size of the underlying storage. Note : this is valid initially and after a commit but is not defined after write is called.

fn read(&self, start: u64, data: &mut [u8])

Read data.

fn write(&mut self, start: u64, data: &[u8])

Write byte slice to storage.

fn commit(&mut self, size: u64)

Finish write transaction, size is new size of underlying storage.

Provided Methods

fn write_vec(&mut self, start: u64, data: Vec<u8>)

Write byte Vec.

fn write_data(&mut self, start: u64, data: Data, off: usize, len: usize)

Write Data slice.

fn write_u64(&mut self, start: u64, value: u64)

Write u64.

fn read_u64(&self, start: u64) -> u64

Read u64.

fn clone(&self) -> Box<dyn Storage>

Clone. note: provided method panics.

fn wait_complete(&self)

Wait until current writes are complete.

Implementors