pub struct AtomicFile { /* private fields */ }Expand description
Based on BasicAtomicFile which makes sure that updates are all-or-nothing. Performs commit asyncronously.
#Example
use atom_file::{AtomicFile,DummyFile,MemFile,Storage};
let mut af = AtomicFile::new(MemFile::new(), DummyFile::new());
af.write( 0, &[1,2,3,4] );
af.commit(4);
af.wait_complete();Atomic file has two maps of writes. On commit, the latest batch of writes are sent to be written to underlying storage, and are also applied to the second map in the “CommitFile”. The CommitFile map is reset when all the updates to underlying storage have been applied.
Implementations